aboutsummaryrefslogtreecommitdiff
path: root/library.h
diff options
context:
space:
mode:
authorPetr Machata <pmachata@redhat.com>2012-03-16 02:46:18 +0100
committerPetr Machata <pmachata@redhat.com>2012-04-19 01:12:51 +0200
commit74132a447b18c588c698ecfb8cf4ad4b16360f2f (patch)
treee1d896bdb056c1602f4139c28b40d19f2e55175b /library.h
parent522a6ca083c8b9e964548b0e79a4bdc8095d6e2e (diff)
downloadltrace-74132a447b18c588c698ecfb8cf4ad4b16360f2f.tar.gz
Change iterators each_task, each_process, library_each_symbol
... now the restarts are supported by start_after instead of start. Otherwise the restart scenario was something like: for (it *sym = NULL; (sym = next(sym)) != NULL; ) if ((sym = sym->next) == NULL) break; which just seems too convoluted.
Diffstat (limited to 'library.h')
-rw-r--r--library.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/library.h b/library.h
index 17f0c1b..13a4cab 100644
--- a/library.h
+++ b/library.h
@@ -120,10 +120,10 @@ void library_destroy(struct library *lib);
void library_set_name(struct library *lib, const char *new_name, int own_name);
/* Iterate through list of symbols of library LIB. Restarts are
* supported via START (see each_process for details of iteration
* interface). */
struct library_symbol *library_each_symbol
- (struct library *lib, struct library_symbol *start,
+ (struct library *lib, struct library_symbol *start_after,
enum callback_status (*cb)(struct library_symbol *, void *),
void *data);
@@ -120,10 +120,10 @@ void library_destroy(struct library *lib);
void library_set_name(struct library *lib, const char *new_name, int own_name);
/* Iterate through list of symbols of library LIB. Restarts are
- * supported via START (see each_process for details of iteration
- * interface). */
+ * supported via START_AFTER (see each_process for details of
+ * iteration interface). */
struct library_symbol *library_each_symbol